# Generated by roxygen2: do not edit by hand

export(lc_fullname)
export(lc_get_comid)
export(lc_get_data)
export(lc_get_metric_names)
export(lc_get_nlcd)
export(lc_get_nni)
export(lc_get_params)
export(lc_get_watershed)
export(lc_plotnni)
export(sc_fullname)
export(sc_get_comid)
export(sc_get_data)
export(sc_get_metric_names)
export(sc_get_nlcd)
export(sc_get_nni)
export(sc_get_params)
export(sc_plotnni)
import(ggpattern)
import(ggplot2)
importFrom(curl,curl_fetch_memory)
